ad_library {

	Library for Mash Up : Newsfeeds

    @author Hamilton Chua (ham@solutiongrove.com)
    @creation-date 2006-03-20
}

namespace eval mashup::newsfeed { }

# ******* FEEDS ***********

ad_proc -public mashup::newsfeed::new {
	-user_id
	-source_id
} {
	Accepts user_id and feed source id. 
	if user is REGISTERED
		Adds this feed to the user's news aggregator, 
		creates a default aggregator if user does not have one.
	if user is NOT registered
		just add to the mashup_feeds table
} {
	set num_of_entries 5
	if { [mashup::user_is_registered -user_id $user_id] } {
		set aggregator_id [mashup::newsfeed::userinit -user_id $user_id]
		news_aggregator::subscription::new -aggregator_id $aggregator_id -source_id $source_id
	}
	set id [db_nextval "mashup_feeds_id"]
	db_dml "insertfeed" "insert into mashup_feeds (id,feed_type,user_id,source_id,num_of_entries) values (:id,'news',:user_id,:source_id,:num_of_entries)"
	return $id
}

ad_proc -public mashup::newsfeed::del {
	-user_id
	-id
} {
	Unsubscribes user from the given source_id
} {
	if { [db_0or1row "getsourceid" "select source_id from mashup_feeds where id=:id"] } {
		if { [mashup::user_is_registered -user_id $user_id] } {
			set aggregator_id [news_aggregator::aggregator::user_default -user_id $user_id -package_id [apm_package_id_from_key "news-aggregator"]]
			news_aggregator::subscription::delete -source_id $source_id -aggregator_id $aggregator_id
		}
		db_dml "delfeed" "delete from mashup_feeds where id=:id"
	}
}

ad_proc -public mashup::newsfeed::delall {
	-user_id
} {
	Unsubscribes all the feeds of a given user_id
} {
	set aggregator_id [news_aggregator::aggregator::user_default -user_id $user_id -package_id [apm_package_id_from_key "news-aggregator"]]
	if { [mashup::user_is_registered -user_id $user_id] } {
		db_foreach "userfeeds" "select source_id from mashup_feeds where user_id=:user_id" {		
				news_aggregator::subscription::delete -source_id $source_id -aggregator_id $aggregator_id
		}
	}
	db_dml "delfeed" "delete from mashup_feeds where user_id=:user_id"
}

ad_proc -private mashup::newsfeed::userinit {
	-user_id
} {
	Determines if the user has an existing aggregator.
	If YES, then the user's default aggregator id is returned.
	If NO, a default aggregator is created for the user and its id is returned.
} {
	# get the aggregator package_id
	set package_id [apm_package_id_from_key "news-aggregator"]
	if { [mashup::user_is_registered -user_id $user_id] } {
		set aggregator_id [news_aggregator::aggregator::user_default \
				-user_id $user_id -package_id $package_id]
	
		if { !$aggregator_id } {
	
			set user_name [person::name -person_id $user_id]
			set aggregator_name "${user_name}'s News Aggregator"
		
			set aggregator_id [news_aggregator::aggregator::new \
						-aggregator_name $aggregator_name \
						-package_id $package_id \
						-public_p 0 \
						-creation_user $user_id \
						-creation_ip [ad_conn peeraddr]]
		
			news_aggregator::aggregator::set_user_default -user_id $user_id \
			-package_id $package_id -aggregator_id $aggregator_id
		
			#load preinstalled subscriptions into aggregator
			news_aggregator::aggregator::load_preinstalled_subscriptions \
			-aggregator_id $aggregator_id \
			-package_id $package_id
		}
	
		return $aggregator_id
	} else {
		return ""
	}
}
